@@ -1,16 +1,17 @@
 import ee
 import geopy
 from geopy.geocoders import get_geocoder_for_service
+
+from .common import (_convert_lnglats_to_pluscodes,
+                     _convert_pluscodes_to_lnglats, _lnglat_from_location,
+                     _retrieve_location)
 from .extending import extend
-from .common import _retrieve_location
-from .common import _lnglat_from_location
-from .common import _convert_lnglats_to_pluscodes
-from .common import _convert_pluscodes_to_lnglats
 
 
 @extend(ee.geometry.Geometry, static=True)
 def BBoxFromQuery(query, geocoder="nominatim", **kwargs):
-    """Constructs an ee.Geometry describing a bounding box from a query submitted to a geodocer using the geopy package.
+    """Constructs an ee.Geometry describing a bounding box from a query submitted to a
+    geodocer using the geopy package.
 
     Tip
     ----------
@@ -21,10 +22,12 @@ def BBoxFromQuery(query, geocoder="nominatim", **kwargs):
     query : str
         Address, query or structured query to geocode.
     geocoder : str, default = 'nominatim'
-        Geocoder to use. One of 'nominatim' or 'arcgis'. Please visit https://geopy.readthedocs.io/ for more info.
+        Geocoder to use. One of 'nominatim' or 'arcgis'. Please visit
+        https://geopy.readthedocs.io/ for more info.
     **kwargs :
-        Keywords arguments for geolocator.geocode(). The user_agent argument is mandatory (this argument can be set as user_agent = 'my-gee-username' or
-        user_agent = 'my-gee-app-name'). Please visit https://geopy.readthedocs.io/ for more info.
+        Keywords arguments for geolocator.geocode(). The user_agent argument is mandatory
+        (this argument can be set as user_agent = 'my-gee-username' or user_agent =
+        'my-gee-app-name'). Please visit https://geopy.readthedocs.io/ for more info.
 
     Returns
     -------
@@ -33,8 +36,10 @@ def BBoxFromQuery(query, geocoder="nominatim", **kwargs):
 
     See Also
     --------
-    PointFromQuery : Constructs an ee.Geometry describing a point from a query submitted to a geodocer using the geopy package.
-    MultiPointFromQuery : Constructs an ee.Geometry describing a multi-point from a query submitted to a geodocer using the geopy package.
+    PointFromQuery : Constructs an ee.Geometry describing a point from a query submitted
+        to a geodocer using the geopy package.
+    MultiPointFromQuery : Constructs an ee.Geometry describing a multi-point from a query
+        submitted to a geodocer using the geopy package.
 
     Examples
     --------
@@ -94,7 +99,10 @@ def BBoxFromQuery(query, geocoder="nominatim", **kwargs):
 
 @extend(ee.geometry.Geometry, static=True)
 def PointFromQuery(query, geocoder="nominatim", **kwargs):
-    """Constructs an ee.Geometry describing a point from a query submitted to a geodocer using the geopy package. This returns exactly one pair of coordinates.
+    """Constructs an ee.Geometry describing a point from a query submitted to a geodocer
+    using the geopy package.
+
+    This returns exactly one pair of coordinates.
 
     Tip
     ----------
@@ -107,8 +115,9 @@ def PointFromQuery(query, geocoder="nominatim", **kwargs):
     geocoder : str, default = 'nominatim'
         Geocoder to use. Please visit https://geopy.readthedocs.io/ for more info.
     **kwargs :
-        Keywords arguments for geolocator.geocode(). The user_agent argument is mandatory (this argument can be set as user_agent = 'my-gee-username' or
-        user_agent = 'my-gee-app-name'). Please visit https://geopy.readthedocs.io/ for more info.
+        Keywords arguments for geolocator.geocode(). The user_agent argument is mandatory
+        (this argument can be set as user_agent = 'my-gee-username' or user_agent =
+        'my-gee-app-name'). Please visit https://geopy.readthedocs.io/ for more info.
 
     Returns
     -------
@@ -117,8 +126,10 @@ def PointFromQuery(query, geocoder="nominatim", **kwargs):
 
     See Also
     --------
-    BBoxFromQuery : Constructs an ee.Geometry describing a bounding box from a query submitted to a geodocer using the geopy package.
-    MultiPointFromQuery : Constructs an ee.Geometry describing a multi-point from a query submitted to a geodocer using the geopy package.
+    BBoxFromQuery : Constructs an ee.Geometry describing a bounding box from a query
+        submitted to a geodocer using the geopy package.
+    MultiPointFromQuery : Constructs an ee.Geometry describing a multi-point from a query
+        submitted to a geodocer using the geopy package.
 
     Examples
     --------
@@ -146,7 +157,10 @@ def PointFromQuery(query, geocoder="nominatim", **kwargs):
 
 @extend(ee.geometry.Geometry, static=True)
 def MultiPointFromQuery(query, geocoder="nominatim", **kwargs):
-    """Constructs an ee.Geometry describing a multi-point from a query submitted to a geodocer using the geopy package. This returns all pairs of coordinates retrieved by the query.
+    """Constructs an ee.Geometry describing a multi-point from a query submitted to a
+    geodocer using the geopy package.
+
+    This returns all pairs of coordinates retrieved by the query.
 
     Tip
     ----------
@@ -159,8 +173,9 @@ def MultiPointFromQuery(query, geocoder="nominatim", **kwargs):
     geocoder : str, default = 'nominatim'
         Geocoder to use. Please visit https://geopy.readthedocs.io/ for more info.
     **kwargs :
-        Keywords arguments for geolocator.geocode(). The user_agent argument is mandatory (this argument can be set as user_agent = 'my-gee-username' or
-        user_agent = 'my-gee-app-name'). Please visit https://geopy.readthedocs.io/ for more info.
+        Keywords arguments for geolocator.geocode(). The user_agent argument is mandatory
+        (this argument can be set as user_agent = 'my-gee-username' or user_agent =
+        'my-gee-app-name'). Please visit https://geopy.readthedocs.io/ for more info.
 
     Returns
     -------
@@ -169,8 +184,10 @@ def MultiPointFromQuery(query, geocoder="nominatim", **kwargs):
 
     See Also
     --------
-    BBoxFromQuery : Constructs an ee.Geometry describing a bounding box from a query submitted to a geodocer using the geopy package.
-    PointFromQuery : Constructs an ee.Geometry describing a point from a query submitted to a geodocer using the geopy package.
+    BBoxFromQuery : Constructs an ee.Geometry describing a bounding box from a query
+        submitted to a geodocer using the geopy package.
+    PointFromQuery : Constructs an ee.Geometry describing a point from a query submitted
+        to a geodocer using the geopy package.
 
     Examples
     --------
@@ -217,8 +234,9 @@ def MultiPointFromQuery(query, geocoder="nominatim", **kwargs):
 def PointFromPlusCode(pluscode, geocoder="nominatim", **kwargs):
     """Constructs an ee.Geometry describing a point from a Plus Code.
 
-    If the Plus Code is full, it will be decoded directly using the openlocationcode package. If it is a short Code with
-    a reference location, the reference will be geocoded using the geopy package.
+    If the Plus Code is full, it will be decoded directly using the openlocationcode
+    package. If it is a short Code with a reference location, the reference will be
+    geocoded using the geopy package.
 
     Tip
     ----------
@@ -231,8 +249,9 @@ def PointFromPlusCode(pluscode, geocoder="nominatim", **kwargs):
     geocoder : str, default = 'nominatim'
         Geocoder to use. Please visit https://geopy.readthedocs.io/ for more info.
     **kwargs :
-        Keywords arguments for geolocator.geocode(). The user_agent argument is mandatory (this argument can be set as user_agent = 'my-gee-username' or
-        user_agent = 'my-gee-app-name'). Please visit https://geopy.readthedocs.io/ for more info.
+        Keywords arguments for geolocator.geocode(). The user_agent argument is mandatory
+        (this argument can be set as user_agent = 'my-gee-username' or user_agent =
+        'my-gee-app-name'). Please visit https://geopy.readthedocs.io/ for more info.
 
     Returns
     -------
@@ -241,20 +260,28 @@ def PointFromPlusCode(pluscode, geocoder="nominatim", **kwargs):
 
     See Also
     --------
-    MultiPointFromPlusCodes : Constructs an ee.Geometry describing multiple points from a list of Plus Codes.
-    PolygonFromPlusCodes : Constructs an ee.Geometry describing a polygon from a list of Plus Codes.
-    MultiPolygonFromPlusCodes : Constructs an ee.Geometry describing multiple polygons from a list of lists of Plus Codes.
-    LineStringFromPlusCodes : Constructs an ee.Geometry describing a line from a list of Plus Codes.
-    MultiLineStringFromPlusCodes : Constructs an ee.Geometry describing multiple lines from a list of lists of Plus Codes.
-    LinearRingFromPlusCodes : Constructs an ee.Geometry describing a linear ring from a list of Plus Codes.
-    RectangleFromPlusCodes : Constructs an ee.Geometry describing a rectangle from a list of two Plus Code corners.
+    MultiPointFromPlusCodes : Constructs an ee.Geometry describing multiple points from a
+        list of Plus Codes.
+    PolygonFromPlusCodes : Constructs an ee.Geometry describing a polygon from a list of
+        Plus Codes.
+    MultiPolygonFromPlusCodes : Constructs an ee.Geometry describing multiple polygons
+        from a list of lists of Plus Codes.
+    LineStringFromPlusCodes : Constructs an ee.Geometry describing a line from a list of
+        Plus Codes.
+    MultiLineStringFromPlusCodes : Constructs an ee.Geometry describing multiple lines
+        from a list of lists of Plus Codes.
+    LinearRingFromPlusCodes : Constructs an ee.Geometry describing a linear ring from a
+        list of Plus Codes.
+    RectangleFromPlusCodes : Constructs an ee.Geometry describing a rectangle from a list
+        of two Plus Code corners.
 
     Examples
     --------
     >>> import ee, eemont
     >>> ee.Authenticate()
     >>> ee.Initialize()
-    >>> geom = ee.Geometry.PointFromPlusCode('QXGV+XH Denver, CO, USA',user_agent = 'my-gee-eemont-query')
+    >>> geom = ee.Geometry.PointFromPlusCode('QXGV+XH Denver, CO, USA',
+    ...                                      user_agent = 'my-gee-eemont-query')
     >>> geom.coordinates().getInfo()
     [-105.0060625, 39.777437500000005]
     """
@@ -266,8 +293,9 @@ def PointFromPlusCode(pluscode, geocoder="nominatim", **kwargs):
 def MultiPointFromPlusCodes(pluscodes, geocoder="nominatim", **kwargs):
     """Constructs an ee.Geometry describing multiple points from a list of Plus Codes.
 
-    If the Plus Codes are full, they will be decoded directly using the openlocationcode package. If they are short Codes with
-    reference locations, the references will be geocoded using the geopy package.
+    If the Plus Codes are full, they will be decoded directly using the openlocationcode
+    package. If they are short Codes with reference locations, the references will be
+    geocoded using the geopy package.
 
     Tip
     ----------
@@ -276,12 +304,14 @@ def MultiPointFromPlusCodes(pluscodes, geocoder="nominatim", **kwargs):
     Parameters
     ----------
     pluscodes : str
-        A list of full Plus Codes or short Plus Codes with geocodable reference locations appended to them.
+        A list of full Plus Codes or short Plus Codes with geocodable reference locations
+        appended to them.
     geocoder : str, default = 'nominatim'
         Geocoder to use. Please visit https://geopy.readthedocs.io/ for more info.
     **kwargs :
-        Keywords arguments for geolocator.geocode(). The user_agent argument is mandatory (this argument can be set as user_agent = 'my-gee-username' or
-        user_agent = 'my-gee-app-name'). Please visit https://geopy.readthedocs.io/ for more info.
+        Keywords arguments for geolocator.geocode(). The user_agent argument is mandatory
+        (this argument can be set as user_agent = 'my-gee-username' or user_agent =
+        'my-gee-app-name'). Please visit https://geopy.readthedocs.io/ for more info.
 
     Returns
     -------
@@ -291,12 +321,18 @@ def MultiPointFromPlusCodes(pluscodes, geocoder="nominatim", **kwargs):
     See Also
     --------
     PointFromPlusCode : Constructs an ee.Geometry describing a point from a Plus Code.
-    PolygonFromPlusCodes : Constructs an ee.Geometry describing a polygon from a list of Plus Codes.
-    MultiPolygonFromPlusCodes : Constructs an ee.Geometry describing multiple polygons from a list of lists of Plus Codes.
-    LineStringFromPlusCodes : Constructs an ee.Geometry describing a line from a list of Plus Codes.
-    MultiLineStringFromPlusCodes : Constructs an ee.Geometry describing multiple lines from a list of lists of Plus Codes.
-    LinearRingFromPlusCodes : Constructs an ee.Geometry describing a linear ring from a list of Plus Codes.
-    RectangleFromPlusCodes : Constructs an ee.Geometry describing a rectangle from a list of two Plus Code corners.
+    PolygonFromPlusCodes : Constructs an ee.Geometry describing a polygon from a list of
+        Plus Codes.
+    MultiPolygonFromPlusCodes : Constructs an ee.Geometry describing multiple polygons
+        from a list of lists of Plus Codes.
+    LineStringFromPlusCodes : Constructs an ee.Geometry describing a line from a list of
+        Plus Codes.
+    MultiLineStringFromPlusCodes : Constructs an ee.Geometry describing multiple lines
+        from a list of lists of Plus Codes.
+    LinearRingFromPlusCodes : Constructs an ee.Geometry describing a linear ring from a
+        list of Plus Codes.
+    RectangleFromPlusCodes : Constructs an ee.Geometry describing a rectangle from a list
+        of two Plus Code corners.
 
     Examples
     --------
@@ -315,8 +351,9 @@ def MultiPointFromPlusCodes(pluscodes, geocoder="nominatim", **kwargs):
 def PolygonFromPlusCodes(pluscodes, geocoder="nominatim", **kwargs):
     """Constructs an ee.Geometry describing a polygon from a list of Plus Codes.
 
-    If the Plus Codes are full, they will be decoded directly using the openlocationcode package. If they are short Codes with
-    reference locations, the references will be geocoded using the geopy package.
+    If the Plus Codes are full, they will be decoded directly using the openlocationcode
+    package. If they are short Codes with reference locations, the references will be
+    geocoded using the geopy package.
 
     Tip
     ----------
@@ -325,12 +362,14 @@ def PolygonFromPlusCodes(pluscodes, geocoder="nominatim", **kwargs):
     Parameters
     ----------
     pluscodes : str
-        A list of full Plus Codes or short Plus Codes with geocodable reference locations appended to them.
+        A list of full Plus Codes or short Plus Codes with geocodable reference locations
+        appended to them.
     geocoder : str, default = 'nominatim'
         Geocoder to use. Please visit https://geopy.readthedocs.io/ for more info.
     **kwargs :
-        Keywords arguments for geolocator.geocode(). The user_agent argument is mandatory (this argument can be set as user_agent = 'my-gee-username' or
-        user_agent = 'my-gee-app-name'). Please visit https://geopy.readthedocs.io/ for more info.
+        Keywords arguments for geolocator.geocode(). The user_agent argument is mandatory
+        (this argument can be set as user_agent = 'my-gee-username' or user_agent =
+        'my-gee-app-name'). Please visit https://geopy.readthedocs.io/ for more info.
 
     Returns
     -------
@@ -340,12 +379,18 @@ def PolygonFromPlusCodes(pluscodes, geocoder="nominatim", **kwargs):
     See Also
     --------
     PointFromPlusCode : Constructs an ee.Geometry describing a point from a Plus Code.
-    MultiPointFromPlusCodes : Constructs an ee.Geometry describing multiple points from a list of Plus Codes.
-    MultiPolygonFromPlusCodes : Constructs an ee.Geometry describing multiple polygons from a list of lists of Plus Codes.
-    LineStringFromPlusCodes : Constructs an ee.Geometry describing a line from a list of Plus Codes.
-    MultiLineStringFromPlusCodes : Constructs an ee.Geometry describing multiple lines from a list of lists of Plus Codes.
-    LinearRingFromPlusCodes : Constructs an ee.Geometry describing a linear ring from a list of Plus Codes.
-    RectangleFromPlusCodes : Constructs an ee.Geometry describing a rectangle from a list of two Plus Code corners.
+    MultiPointFromPlusCodes : Constructs an ee.Geometry describing multiple points from a
+        list of Plus Codes.
+    MultiPolygonFromPlusCodes : Constructs an ee.Geometry describing multiple polygons
+        from a list of lists of Plus Codes.
+    LineStringFromPlusCodes : Constructs an ee.Geometry describing a line from a list of
+        Plus Codes.
+    MultiLineStringFromPlusCodes : Constructs an ee.Geometry describing multiple lines
+        from a list of lists of Plus Codes.
+    LinearRingFromPlusCodes : Constructs an ee.Geometry describing a linear ring from a
+        list of Plus Codes.
+    RectangleFromPlusCodes : Constructs an ee.Geometry describing a rectangle from a list
+        of two Plus Code corners.
 
     Examples
     --------
@@ -365,10 +410,12 @@ def PolygonFromPlusCodes(pluscodes, geocoder="nominatim", **kwargs):
 
 @extend(ee.geometry.Geometry, static=True)
 def MultiPolygonFromPlusCodes(pluscodes, geocoder="nominatim", **kwargs):
-    """Constructs an ee.Geometry describing multiple polygons from a list of lists of Plus Codes.
+    """Constructs an ee.Geometry describing multiple polygons from a list of lists of
+    Plus Codes.
 
-    If the Plus Codes are full, they will be decoded directly using the openlocationcode package. If they are short Codes with
-    reference locations, the references will be geocoded using the geopy package.
+    If the Plus Codes are full, they will be decoded directly using the openlocationcode
+    package. If they are short Codes with reference locations, the references will be
+    geocoded using the geopy package.
 
     Tip
     ----------
@@ -377,12 +424,14 @@ def MultiPolygonFromPlusCodes(pluscodes, geocoder="nominatim", **kwargs):
     Parameters
     ----------
     pluscodes : str
-        A list of lists of full Plus Codes or short Plus Codes with geocodable reference locations appended to them.
+        A list of lists of full Plus Codes or short Plus Codes with geocodable reference
+        locations appended to them.
     geocoder : str, default = 'nominatim'
         Geocoder to use. Please visit https://geopy.readthedocs.io/ for more info.
     **kwargs :
-        Keywords arguments for geolocator.geocode(). The user_agent argument is mandatory (this argument can be set as user_agent = 'my-gee-username' or
-        user_agent = 'my-gee-app-name'). Please visit https://geopy.readthedocs.io/ for more info.
+        Keywords arguments for geolocator.geocode(). The user_agent argument is mandatory
+        (this argument can be set as user_agent = 'my-gee-username' or user_agent =
+        'my-gee-app-name'). Please visit https://geopy.readthedocs.io/ for more info.
 
     Returns
     -------
@@ -392,19 +441,28 @@ def MultiPolygonFromPlusCodes(pluscodes, geocoder="nominatim", **kwargs):
     See Also
     --------
     PointFromPlusCode : Constructs an ee.Geometry describing a point from a Plus Code.
-    MultiPointFromPlusCodes : Constructs an ee.Geometry describing multiple points from a list of Plus Codes.
-    PolygonFromPlusCodes : Constructs an ee.Geometry describing a polygon from a list of Plus Codes.
-    LineStringFromPlusCodes : Constructs an ee.Geometry describing a line from a list of Plus Codes.
-    MultiLineStringFromPlusCodes : Constructs an ee.Geometry describing multiple lines from a list of lists of Plus Codes.
-    LinearRingFromPlusCodes : Constructs an ee.Geometry describing a linear ring from a list of Plus Codes.
-    RectangleFromPlusCodes : Constructs an ee.Geometry describing a rectangle from a list of two Plus Code corners.
+    MultiPointFromPlusCodes : Constructs an ee.Geometry describing multiple points from a
+        list of Plus Codes.
+    PolygonFromPlusCodes : Constructs an ee.Geometry describing a polygon from a list of
+        Plus Codes.
+    LineStringFromPlusCodes : Constructs an ee.Geometry describing a line from a list of
+        Plus Codes.
+    MultiLineStringFromPlusCodes : Constructs an ee.Geometry describing multiple lines
+        from a list of lists of Plus Codes.
+    LinearRingFromPlusCodes : Constructs an ee.Geometry describing a linear ring from a
+        list of Plus Codes.
+    RectangleFromPlusCodes : Constructs an ee.Geometry describing a rectangle from a list
+        of two Plus Code corners.
 
     Examples
     --------
     >>> import ee, eemont
     >>> ee.Authenticate()
     >>> ee.Initialize()
-    >>> geom = ee.Geometry.MultiPolygonFromPlusCodes([['85FQ2222+22', '85FR2222+22', '85GR2222+22'],['85FP8PC2+G2', '85FPJF23+G4', '85FPMW2R+RP']])
+    >>> geom = ee.Geometry.MultiPolygonFromPlusCodes([
+    ...    ['85FQ2222+22', '85FR2222+22', '85GR2222+22'],
+    ...    ['85FP8PC2+G2', '85FPJF23+G4', '85FPMW2R+RP']
+    ...  ])
     >>> geom.coordinates().getInfo()
     [[[[-104.9999375, 39.0000625],
       [-103.9999375, 39.0000625],
@@ -423,8 +481,9 @@ def MultiPolygonFromPlusCodes(pluscodes, geocoder="nominatim", **kwargs):
 def LineStringFromPlusCodes(pluscodes, geocoder="nominatim", **kwargs):
     """Constructs an ee.Geometry describing a line from a list of Plus Codes.
 
-    If the Plus Codes are full, they will be decoded directly using the openlocationcode package. If they are short Codes with
-    reference locations, the references will be geocoded using the geopy package.
+    If the Plus Codes are full, they will be decoded directly using the openlocationcode
+    package. If they are short Codes with reference locations, the references will be
+    geocoded using the geopy package.
 
     Tip
     ----------
@@ -433,12 +492,14 @@ def LineStringFromPlusCodes(pluscodes, geocoder="nominatim", **kwargs):
     Parameters
     ----------
     pluscodes : str
-        A list of full Plus Codes or short Plus Codes with geocodable reference locations appended to them.
+        A list of full Plus Codes or short Plus Codes with geocodable reference locations
+        appended to them.
     geocoder : str, default = 'nominatim'
         Geocoder to use. Please visit https://geopy.readthedocs.io/ for more info.
     **kwargs :
-        Keywords arguments for geolocator.geocode(). The user_agent argument is mandatory (this argument can be set as user_agent = 'my-gee-username' or
-        user_agent = 'my-gee-app-name'). Please visit https://geopy.readthedocs.io/ for more info.
+        Keywords arguments for geolocator.geocode(). The user_agent argument is mandatory
+        (this argument can be set as user_agent = 'my-gee-username' or user_agent =
+        'my-gee-app-name'). Please visit https://geopy.readthedocs.io/ for more info.
 
     Returns
     -------
@@ -448,12 +509,18 @@ def LineStringFromPlusCodes(pluscodes, geocoder="nominatim", **kwargs):
     See Also
     --------
     PointFromPlusCode : Constructs an ee.Geometry describing a point from a Plus Code.
-    MultiPointFromPlusCodes : Constructs an ee.Geometry describing multiple points from a list of Plus Codes.
-    PolygonFromPlusCodes : Constructs an ee.Geometry describing a polygon from a list of Plus Codes.
-    MultiPolygonFromPlusCodes : Constructs an ee.Geometry describing multiple polygons from a list of lists of Plus Codes.
-    MultiLineStringFromPlusCodes : Constructs an ee.Geometry describing multiple lines from a list of lists of Plus Codes.
-    LinearRingFromPlusCodes : Constructs an ee.Geometry describing a linear ring from a list of Plus Codes.
-    RectangleFromPlusCodes : Constructs an ee.Geometry describing a rectangle from a list of two Plus Code corners.
+    MultiPointFromPlusCodes : Constructs an ee.Geometry describing multiple points from a
+        list of Plus Codes.
+    PolygonFromPlusCodes : Constructs an ee.Geometry describing a polygon from a list of
+        Plus Codes.
+    MultiPolygonFromPlusCodes : Constructs an ee.Geometry describing multiple polygons
+        from a list of lists of Plus Codes.
+    MultiLineStringFromPlusCodes : Constructs an ee.Geometry describing multiple lines
+        from a list of lists of Plus Codes.
+    LinearRingFromPlusCodes : Constructs an ee.Geometry describing a linear ring from a
+        list of Plus Codes.
+    RectangleFromPlusCodes : Constructs an ee.Geometry describing a rectangle from a list
+        of two Plus Code corners.
 
     Examples
     --------
@@ -470,10 +537,12 @@ def LineStringFromPlusCodes(pluscodes, geocoder="nominatim", **kwargs):
 
 @extend(ee.geometry.Geometry, static=True)
 def MultiLineStringFromPlusCodes(pluscodes, geocoder="nominatim", **kwargs):
-    """Constructs an ee.Geometry describing multiple lines from a list of lists of Plus Codes.
+    """Constructs an ee.Geometry describing multiple lines from a list of lists of Plus
+    Codes.
 
-    If the Plus Codes are full, they will be decoded directly using the openlocationcode package. If they are short Codes with
-    reference locations, the references will be geocoded using the geopy package.
+    If the Plus Codes are full, they will be decoded directly using the openlocationcode
+    package. If they are short Codes with reference locations, the references will be
+    geocoded using the geopy package.
 
     Tip
     ----------
@@ -482,12 +551,14 @@ def MultiLineStringFromPlusCodes(pluscodes, geocoder="nominatim", **kwargs):
     Parameters
     ----------
     pluscodes : str
-        A list of lists of full Plus Codes or short Plus Codes with geocodable reference locations appended to them.
+        A list of lists of full Plus Codes or short Plus Codes with geocodable reference
+        locations appended to them.
     geocoder : str, default = 'nominatim'
         Geocoder to use. Please visit https://geopy.readthedocs.io/ for more info.
     **kwargs :
-        Keywords arguments for geolocator.geocode(). The user_agent argument is mandatory (this argument can be set as user_agent = 'my-gee-username' or
-        user_agent = 'my-gee-app-name'). Please visit https://geopy.readthedocs.io/ for more info.
+        Keywords arguments for geolocator.geocode(). The user_agent argument is mandatory
+        (this argument can be set as user_agent = 'my-gee-username' or user_agent =
+        'my-gee-app-name'). Please visit https://geopy.readthedocs.io/ for more info.
 
     Returns
     -------
@@ -497,19 +568,28 @@ def MultiLineStringFromPlusCodes(pluscodes, geocoder="nominatim", **kwargs):
     See Also
     --------
     PointFromPlusCode : Constructs an ee.Geometry describing a point from a Plus Code.
-    MultiPointFromPlusCodes : Constructs an ee.Geometry describing multiple points from a list of Plus Codes.
-    PolygonFromPlusCodes : Constructs an ee.Geometry describing a polygon from a list of Plus Codes.
-    MultiPolygonFromPlusCodes : Constructs an ee.Geometry describing multiple polygons from a list of lists of Plus Codes.
-    LineStringFromPlusCodes : Constructs an ee.Geometry describing a line from a list of Plus Codes.
-    LinearRingFromPlusCodes : Constructs an ee.Geometry describing a linear ring from a list of Plus Codes.
-    RectangleFromPlusCodes : Constructs an ee.Geometry describing a rectangle from a list of two Plus Code corners.
+    MultiPointFromPlusCodes : Constructs an ee.Geometry describing multiple points from a
+        list of Plus Codes.
+    PolygonFromPlusCodes : Constructs an ee.Geometry describing a polygon from a list of
+        Plus Codes.
+    MultiPolygonFromPlusCodes : Constructs an ee.Geometry describing multiple polygons
+        from a list of lists of Plus Codes.
+    LineStringFromPlusCodes : Constructs an ee.Geometry describing a line from a list of
+        Plus Codes.
+    LinearRingFromPlusCodes : Constructs an ee.Geometry describing a linear ring from a
+        list of Plus Codes.
+    RectangleFromPlusCodes : Constructs an ee.Geometry describing a rectangle from a list
+        of two Plus Code corners.
 
     Examples
     --------
     >>> import ee, eemont
     >>> ee.Authenticate()
     >>> ee.Initialize()
-    >>> geom = ee.Geometry.MultiLineStringFromPlusCodes([['85FQ2222+22', '85FR2222+22'],['85FP8PC2+G2', '85FPJF23+G4']])
+    >>> geom = ee.Geometry.MultiLineStringFromPlusCodes([
+    ...    ['85FQ2222+22', '85FR2222+22'],
+    ...    ['85FP8PC2+G2', '85FPJF23+G4']
+    ... ])
     >>> geom.coordinates().getInfo()
     [[[-104.9999375, 39.0000625], [-103.9999375, 39.0000625]],
     [[-105.2999375, 39.321312500000005], [-105.5471875, 39.6013125]]]
@@ -522,8 +602,9 @@ def MultiLineStringFromPlusCodes(pluscodes, geocoder="nominatim", **kwargs):
 def LinearRingFromPlusCodes(pluscodes, geocoder="nominatim", **kwargs):
     """Constructs an ee.Geometry describing a linear ring from a list of Plus Codes.
 
-    If the Plus Codes are full, they will be decoded directly using the openlocationcode package. If they are short Codes with
-    reference locations, the references will be geocoded using the geopy package.
+    If the Plus Codes are full, they will be decoded directly using the openlocationcode
+    package. If they are short Codes with reference locations, the references will be
+    geocoded using the geopy package.
 
     Tip
     ----------
@@ -532,12 +613,14 @@ def LinearRingFromPlusCodes(pluscodes, geocoder="nominatim", **kwargs):
     Parameters
     ----------
     pluscodes : str
-        A list of full Plus Codes or short Plus Codes with geocodable reference locations appended to them.
+        A list of full Plus Codes or short Plus Codes with geocodable reference locations
+        appended to them.
     geocoder : str, default = 'nominatim'
         Geocoder to use. Please visit https://geopy.readthedocs.io/ for more info.
     **kwargs :
-        Keywords arguments for geolocator.geocode(). The user_agent argument is mandatory (this argument can be set as user_agent = 'my-gee-username' or
-        user_agent = 'my-gee-app-name'). Please visit https://geopy.readthedocs.io/ for more info.
+        Keywords arguments for geolocator.geocode(). The user_agent argument is mandatory
+        (this argument can be set as user_agent = 'my-gee-username' or user_agent =
+        'my-gee-app-name'). Please visit https://geopy.readthedocs.io/ for more info.
 
     Returns
     -------
@@ -547,19 +630,26 @@ def LinearRingFromPlusCodes(pluscodes, geocoder="nominatim", **kwargs):
     See Also
     --------
     PointFromPlusCode : Constructs an ee.Geometry describing a point from a Plus Code.
-    MultiPointFromPlusCodes : Constructs an ee.Geometry describing multiple points from a list of Plus Codes.
-    PolygonFromPlusCodes : Constructs an ee.Geometry describing a polygon from a list of Plus Codes.
-    MultiPolygonFromPlusCodes : Constructs an ee.Geometry describing multiple polygons from a list of lists of Plus Codes.
-    LineStringFromPlusCodes : Constructs an ee.Geometry describing a line from a list of Plus Codes.
-    MultiLineStringFromPlusCodes : Constructs an ee.Geometry describing multiple lines from a list of lists of Plus Codes.
-    RectangleFromPlusCodes : Constructs an ee.Geometry describing a rectangle from a list of two Plus Code corners.
+    MultiPointFromPlusCodes : Constructs an ee.Geometry describing multiple points from a
+        list of Plus Codes.
+    PolygonFromPlusCodes : Constructs an ee.Geometry describing a polygon from a list of
+        Plus Codes.
+    MultiPolygonFromPlusCodes : Constructs an ee.Geometry describing multiple polygons
+        from a list of lists of Plus Codes.
+    LineStringFromPlusCodes : Constructs an ee.Geometry describing a line from a list of
+        Plus Codes.
+    MultiLineStringFromPlusCodes : Constructs an ee.Geometry describing multiple lines
+        from a list of lists of Plus Codes.
+    RectangleFromPlusCodes : Constructs an ee.Geometry describing a rectangle from a list
+        of two Plus Code corners.
 
     Examples
     --------
     >>> import ee, eemont
     >>> ee.Authenticate()
     >>> ee.Initialize()
-    >>> geom = ee.Geometry.LinearRingFromPlusCodes(['85FQ2222+22', '85FR2222+22', '85GR2222+22'])
+    >>> geom = ee.Geometry.LinearRingFromPlusCodes(['85FQ2222+22',
+    ...                                             '85FR2222+22', '85GR2222+22'])
     >>> geom.coordinates().getInfo()
     [[-104.9999375, 39.0000625],
     [-103.9999375, 39.0000625],
@@ -572,10 +662,12 @@ def LinearRingFromPlusCodes(pluscodes, geocoder="nominatim", **kwargs):
 
 @extend(ee.geometry.Geometry, static=True)
 def RectangleFromPlusCodes(pluscodes, geocoder="nominatim", **kwargs):
-    """Constructs an ee.Geometry describing a rectangle from a list of two Plus Code corners.
+    """Constructs an ee.Geometry describing a rectangle from a list of two Plus Code
+    corners.
 
-    If the Plus Codes are full, they will be decoded directly using the openlocationcode package. If they are short Codes with
-    reference locations, the references will be geocoded using the geopy package.
+    If the Plus Codes are full, they will be decoded directly using the openlocationcode
+    package. If they are short Codes with reference locations, the references will be
+    geocoded using the geopy package.
 
     Tip
     ----------
@@ -584,12 +676,14 @@ def RectangleFromPlusCodes(pluscodes, geocoder="nominatim", **kwargs):
     Parameters
     ----------
     pluscodes : str
-        A list of two full Plus Codes or short Plus Codes with geocodable reference locations appended to them describing the corners of the rectangle.
+        A list of two full Plus Codes or short Plus Codes with geocodable reference
+        locations appended to them describing the corners of the rectangle.
     geocoder : str, default = 'nominatim'
         Geocoder to use. Please visit https://geopy.readthedocs.io/ for more info.
     **kwargs :
-        Keywords arguments for geolocator.geocode(). The user_agent argument is mandatory (this argument can be set as user_agent = 'my-gee-username' or
-        user_agent = 'my-gee-app-name'). Please visit https://geopy.readthedocs.io/ for more info.
+        Keywords arguments for geolocator.geocode(). The user_agent argument is mandatory
+        (this argument can be set as user_agent = 'my-gee-username' or user_agent =
+        'my-gee-app-name'). Please visit https://geopy.readthedocs.io/ for more info.
 
     Returns
     -------
@@ -599,12 +693,18 @@ def RectangleFromPlusCodes(pluscodes, geocoder="nominatim", **kwargs):
     See Also
     --------
     PointFromPlusCode : Constructs an ee.Geometry describing a point from a Plus Code.
-    MultiPointFromPlusCodes : Constructs an ee.Geometry describing multiple points from a list of Plus Codes.
-    PolygonFromPlusCodes : Constructs an ee.Geometry describing a polygon from a list of Plus Codes.
-    MultiPolygonFromPlusCodes : Constructs an ee.Geometry describing multiple polygons from a list of lists of Plus Codes.
-    LineStringFromPlusCodes : Constructs an ee.Geometry describing a line from a list of Plus Codes.
-    MultiLineStringFromPlusCodes : Constructs an ee.Geometry describing multiple lines from a list of lists of Plus Codes.
-    LinearRingFromPlusCodes : Constructs an ee.Geometry describing a linear ring from a list of Plus Codes.
+    MultiPointFromPlusCodes : Constructs an ee.Geometry describing multiple points from a
+        list of Plus Codes.
+    PolygonFromPlusCodes : Constructs an ee.Geometry describing a polygon from a list of
+        Plus Codes.
+    MultiPolygonFromPlusCodes : Constructs an ee.Geometry describing multiple polygons
+        from a list of lists of Plus Codes.
+    LineStringFromPlusCodes : Constructs an ee.Geometry describing a line from a list of
+        Plus Codes.
+    MultiLineStringFromPlusCodes : Constructs an ee.Geometry describing multiple lines
+        from a list of lists of Plus Codes.
+    LinearRingFromPlusCodes : Constructs an ee.Geometry describing a linear ring from a
+        list of Plus Codes.
 
     Examples
     --------
@@ -632,13 +732,15 @@ def plusCodes(self, codeLength=10):
     self : ee.Geometry
         The geometry to extract coordinates from.
     codeLength : int, default = 10
-        The number of significant digits in the output codes, between 2 and 15. Shorter codes are less precise.
+        The number of significant digits in the output codes, between 2 and 15. Shorter
+        codes are less precise.
 
     Returns
     -------
     list | str
-        The coordinates of the geometry converted to Plus Codes. The structure of the Plus Codes array will be
-        identical to the structure returned by ee.Geometry.coordinates().
+        The coordinates of the geometry converted to Plus Codes. The structure of the Plus
+        Codes array will be identical to the structure returned by
+        ee.Geometry.coordinates().
 
     Examples
     --------
