@@ -492,11 +492,15 @@ def spectralIndices(
     intercept=0.0,
     gamma=1.0,
     omega=2.0,
+    beta=0.05,
     k=0.0,
     kernel="RBF",
     sigma="0.5 * (a + b)",
     p=2.0,
     c=1.0,
+    lambdaN=858.5,
+    lambdaR=645.0,
+    lambdaG=555.0,
     online=False,
     drop=False,
 ):
@@ -519,7 +523,6 @@ def spectralIndices(
             - 'burn' : Compute all burn indices.
             - 'water' : Compute all water indices.
             - 'snow' : Compute all snow indices.
-            - 'drought' : Compute all drought indices.
             - 'urban' : Compute all urban (built-up) indices.
             - 'kernel' : Compute all kernel indices.
             - 'all' : Compute all indices listed below.
@@ -548,6 +551,8 @@ def spectralIndices(
         Weighting coefficient  used for ARVI.
     omega : float, default = 2.0
         Weighting coefficient  used for MBWI.
+    beta : float, default = 0.05
+        Calibration parameter used for NDSIns.
     k : float, default = 0.0
         Slope parameter by soil used for NIRvH2.
     kernel : str, default = 'RBF'
@@ -565,6 +570,12 @@ def spectralIndices(
         Free parameter that trades off the influence of higher-order versus lower-order
         terms in the polynomial kernel. Used for kernel = 'poly'. This must be greater
         than or equal to 0.
+    lambdaN : float, default = 858.5
+        NIR wavelength used for NIRvH2 and NDGI.
+    lambdaR : float, default = 645.0
+        Red wavelength used for NIRvH2 and NDGI.
+    lambdaG : float, default = 555.0
+        Green wavelength used for NDGI.
     online : boolean, default = False
         Whether to retrieve the most recent list of indices directly from the GitHub
         repository and not from the local copy.
@@ -625,11 +636,15 @@ def spectralIndices(
         intercept,
         gamma,
         omega,
+        beta,
         k,
         kernel,
         sigma,
         p,
         c,
+        lambdaN,
+        lambdaR,
+        lambdaG,
         online,
         drop,
     )
@@ -1065,6 +1080,9 @@ def tasseledCap(self):
     supported platforms:
 
     * Sentinel-2 MSI Level 1C [1]_
+    * Landsat 9 OLI-2 SR [2]_
+    * Landsat 9 OLI-2 TOA [2]_
+    * Landsat 8 OLI SR [2]_
     * Landsat 8 OLI TOA [2]_
     * Landsat 7 ETM+ TOA [3]_
     * Landsat 5 TM Raw DN [4]_
@@ -1089,9 +1107,10 @@ def tasseledCap(self):
         Coefficients for Sentinel-2 MSI At-Sensor Reflectance Data. IEEE Journal
         of Selected Topics in Applied Earth Observations and Remote Sensing, 1–11.
         doi:10.1109/jstars.2019.2938388
-    .. [2] Baig, M.H.A., Zhang, L., Shuai, T. and Tong, Q., 2014. Derivation of a
-        tasselled cap transformation based on Landsat 8 at-satellite reflectance.
-        Remote Sensing Letters, 5(5), pp.423-431.
+    .. [2] Zhai, Y., Roy, D.P., Martins, V.S., Zhang, H.K., Yan, L., Li, Z. 2022.
+        Conterminous United States Landsat-8 top of atmosphere and surface reflectance
+        tasseled cap transformation coefficeints. Remote Sensing of Environment, 
+        274(2022). doi:10.1016/j.rse.2022.112992
     .. [3] Huang, C., Wylie, B., Yang, L., Homer, C. and Zylstra, G., 2002.
         Derivation of a tasselled cap transformation based on Landsat 7 at-satellite
         reflectance. International journal of remote sensing, 23(8), pp.1741-1748.
